==> jc-1.4.0.tar.gz: java/lang/VMCompiler.c <==
// final class java.lang.VMCompiler

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 1ec1b2c5fdf4b5df java_lang_VMCompiler

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_VMCompiler

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/VMCompiler.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static final java.lang.Object command(java.lang.Object)
//

static _jc_linenum _jc_java_lang_VMCompiler$linenum_table$command$9c4610a0259285ef[];

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$command$9c4610a0259285ef[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMCompiler$param_types$command$9c4610a0259285ef[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_VMCompiler$method_info$command$9c4610a0259285ef = {
	.name=			"command",
	.signature=		"(Ljava/lang/Object;)Ljava/lang/Object;",
	.class=			&_jc_java_lang_VMCompiler$type,
	.param_types=		&_jc_java_lang_VMCompiler$param_types$command$9c4610a0259285ef,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$command$9c4610a0259285ef,
	.signature_hash=	_JC_JLONG(0x9c4610a0259285ef),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_VMCompiler$method$command$9c4610a0259285ef,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMCompiler$linenum_table$command$9c4610a0259285ef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMCompiler, command$9c4610a0259285ef);

_jc_java_lang_Object$object *
_jc_java_lang_VMCompiler$method$command$9c4610a0259285ef(_jc_env *const env, _jc_java_lang_Object$object *param0)
{
	struct _jc_java_lang_Object$object *r0;

	r0 = param0;
	_JC_LINE_NUMBER(85);				// 0
	return _JC_NULL;
}

//
// public static final native boolean compileClass(java.lang.Class)
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$compileClass$258fd65025401c03[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_lang_VMCompiler$param_types$compileClass$258fd65025401c03[] = {
	&_jc_java_lang_Class$type
};

_jc_method _jc_java_lang_VMCompiler$method_info$compileClass$258fd65025401c03 = {
	.name=			"compileClass",
	.signature=		"(Ljava/lang/Class;)Z",
	.class=			&_jc_java_lang_VMCompiler$type,
	.param_types=		&_jc_java_lang_VMCompiler$param_types$compileClass$258fd65025401c03,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$compileClass$258fd65025401c03,
	.signature_hash=	_JC_JLONG(0x258fd65025401c03),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$compileClass$258fd65025401c03,
	.num_parameters=	1,
};

jboolean
_jc_java_lang_VMCompiler$method$compileClass$258fd65025401c03(_jc_env *const env, _jc_java_lang_Class$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$compileClass$258fd65025401c03, &retval, param0);
	return retval.z;
}

//
// public static final native boolean compileClasses(java.lang.String)
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$compileClasses$f9c43047d6e51ee8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_lang_VMCompiler$param_types$compileClasses$f9c43047d6e51ee8[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_lang_VMCompiler$method_info$compileClasses$f9c43047d6e51ee8 = {
	.name=			"compileClasses",
	.signature=		"(Ljava/lang/String;)Z",
	.class=			&_jc_java_lang_VMCompiler$type,
	.param_types=		&_jc_java_lang_VMCompiler$param_types$compileClasses$f9c43047d6e51ee8,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$compileClasses$f9c43047d6e51ee8,
	.signature_hash=	_JC_JLONG(0xf9c43047d6e51ee8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$compileClasses$f9c43047d6e51ee8,
	.num_parameters=	1,
};

jboolean
_jc_java_lang_VMCompiler$method$compileClasses$f9c43047d6e51ee8(_jc_env *const env, _jc_java_lang_String$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$compileClasses$f9c43047d6e51ee8, &retval, param0);
	return retval.z;
}

//
// public static final native void disable()
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$disable$76bb9c74f42e72e3[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMCompiler$method_info$disable$76bb9c74f42e72e3 = {
	.name=			"disable",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMCompiler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$disable$76bb9c74f42e72e3,
	.signature_hash=	_JC_JLONG(0x76bb9c74f42e72e3),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$disable$76bb9c74f42e72e3,
	.num_parameters=	0,
};

void
_jc_java_lang_VMCompiler$method$disable$76bb9c74f42e72e3(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$disable$76bb9c74f42e72e3, &retval);
}

//
// public static final native void enable()
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$enable$d5c88e4ee7026bca[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMCompiler$method_info$enable$d5c88e4ee7026bca = {
	.name=			"enable",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMCompiler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$enable$d5c88e4ee7026bca,
	.signature_hash=	_JC_JLONG(0xd5c88e4ee7026bca),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$enable$d5c88e4ee7026bca,
	.num_parameters=	0,
};

void
_jc_java_lang_VMCompiler$method$enable$d5c88e4ee7026bca(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$enable$d5c88e4ee7026bca, &retval);
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_java_lang_VMCompiler$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMCompiler$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMCompiler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_java_lang_VMCompiler$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMCompiler$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMCompiler, _init$52f4ad9f2989aeee);

void
_jc_java_lang_VMCompiler$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMCompiler$object *this)
{
	struct _jc_java_lang_VMCompiler$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(51);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMCompiler$methods[] = {
	&_jc_java_lang_VMCompiler$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMCompiler$method_info$command$9c4610a0259285ef,
	&_jc_java_lang_VMCompiler$method_info$compileClass$258fd65025401c03,
	&_jc_java_lang_VMCompiler$method_info$compileClasses$f9c43047d6e51ee8,
	&_jc_java_lang_VMCompiler$method_info$disable$76bb9c74f42e72e3,
	&_jc_java_lang_VMCompiler$method_info$enable$d5c88e4ee7026bca
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMCompiler$instanceof_hash_bucket_95[] = {
	&_jc_java_lang_VMCompiler$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMCompiler$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMCompiler$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[95]=	_jc_java_lang_VMCompiler$instanceof_hash_bucket_95,
	[113]=	_jc_java_lang_VMCompiler$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMCompiler$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMCompiler$vtype _jc_java_lang_VMCompiler$type = {
    .type= {
	.name=			"java/lang/VMCompiler",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x1ec1b2c5fdf4b5df),
		.source_file=		"VMCompiler.java",
		.instance_size=		sizeof(_jc_java_lang_VMCompiler$refs) + sizeof(_jc_java_lang_VMCompiler$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_lang_VMCompiler$methods) / sizeof(*_jc_java_lang_VMCompiler$methods),
		.methods=		_jc_java_lang_VMCompiler$methods,
		.instanceof_hash_table=	_jc_java_lang_VMCompiler$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_VMCompiler$class_depends) / sizeof(*_jc_java_lang_VMCompiler$class_depends),
		.class_depends=		_jc_java_lang_VMCompiler$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMCompiler= {
	},
    }
};

==> jc-1.4.5.tar.gz: java/lang/VMCompiler.c <==
// final class java.lang.VMCompiler

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 1ec1b2c5fdf4b5df java_lang_VMCompiler

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_VMCompiler

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/VMCompiler.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// public static final java.lang.Object command(java.lang.Object)
//

static _jc_linenum _jc_java_lang_VMCompiler$linenum_table$command$9c4610a0259285ef[];

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$command$9c4610a0259285ef[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMCompiler$param_types$command$9c4610a0259285ef[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_VMCompiler$method_info$command$9c4610a0259285ef = {
	.name=			"command",
	.signature=		"(Ljava/lang/Object;)Ljava/lang/Object;",
	.class=			&_jc_java_lang_VMCompiler$type,
	.param_types=		&_jc_java_lang_VMCompiler$param_types$command$9c4610a0259285ef,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$command$9c4610a0259285ef,
	.signature_hash=	_JC_JLONG(0x9c4610a0259285ef),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_VMCompiler$method$command$9c4610a0259285ef,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMCompiler$linenum_table$command$9c4610a0259285ef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMCompiler, command$9c4610a0259285ef);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_lang_VMCompiler$method$command$9c4610a0259285ef(_jc_env *const env, _jc_java_lang_Object$object *param0)
{
	struct _jc_java_lang_Object$object *r0;

	r0 = param0;
	_JC_LINE_NUMBER(85);				// 0
	return _JC_NULL;
}

//
// public static final native boolean compileClass(java.lang.Class)
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$compileClass$258fd65025401c03[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_lang_VMCompiler$param_types$compileClass$258fd65025401c03[] = {
	&_jc_java_lang_Class$type
};

_jc_method _jc_java_lang_VMCompiler$method_info$compileClass$258fd65025401c03 = {
	.name=			"compileClass",
	.signature=		"(Ljava/lang/Class;)Z",
	.class=			&_jc_java_lang_VMCompiler$type,
	.param_types=		&_jc_java_lang_VMCompiler$param_types$compileClass$258fd65025401c03,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$compileClass$258fd65025401c03,
	.signature_hash=	_JC_JLONG(0x258fd65025401c03),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$compileClass$258fd65025401c03,
	.num_parameters=	1,
};

jboolean _JC_JCNI_ATTR
_jc_java_lang_VMCompiler$method$compileClass$258fd65025401c03(_jc_env *const env, _jc_java_lang_Class$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$compileClass$258fd65025401c03, &retval, param0);
	return retval.z;
}

//
// public static final native boolean compileClasses(java.lang.String)
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$compileClasses$f9c43047d6e51ee8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_lang_VMCompiler$param_types$compileClasses$f9c43047d6e51ee8[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_lang_VMCompiler$method_info$compileClasses$f9c43047d6e51ee8 = {
	.name=			"compileClasses",
	.signature=		"(Ljava/lang/String;)Z",
	.class=			&_jc_java_lang_VMCompiler$type,
	.param_types=		&_jc_java_lang_VMCompiler$param_types$compileClasses$f9c43047d6e51ee8,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$compileClasses$f9c43047d6e51ee8,
	.signature_hash=	_JC_JLONG(0xf9c43047d6e51ee8),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$compileClasses$f9c43047d6e51ee8,
	.num_parameters=	1,
};

jboolean _JC_JCNI_ATTR
_jc_java_lang_VMCompiler$method$compileClasses$f9c43047d6e51ee8(_jc_env *const env, _jc_java_lang_String$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$compileClasses$f9c43047d6e51ee8, &retval, param0);
	return retval.z;
}

//
// public static final native void disable()
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$disable$76bb9c74f42e72e3[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMCompiler$method_info$disable$76bb9c74f42e72e3 = {
	.name=			"disable",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMCompiler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$disable$76bb9c74f42e72e3,
	.signature_hash=	_JC_JLONG(0x76bb9c74f42e72e3),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$disable$76bb9c74f42e72e3,
	.num_parameters=	0,
};

void _JC_JCNI_ATTR
_jc_java_lang_VMCompiler$method$disable$76bb9c74f42e72e3(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$disable$76bb9c74f42e72e3, &retval);
}

//
// public static final native void enable()
//

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$enable$d5c88e4ee7026bca[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMCompiler$method_info$enable$d5c88e4ee7026bca = {
	.name=			"enable",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMCompiler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$enable$d5c88e4ee7026bca,
	.signature_hash=	_JC_JLONG(0xd5c88e4ee7026bca),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMCompiler$method$enable$d5c88e4ee7026bca,
	.num_parameters=	0,
};

void _JC_JCNI_ATTR
_jc_java_lang_VMCompiler$method$enable$d5c88e4ee7026bca(_jc_env *const env)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMCompiler$method_info$enable$d5c88e4ee7026bca, &retval);
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_java_lang_VMCompiler$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMCompiler$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMCompiler$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMCompiler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMCompiler$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_java_lang_VMCompiler$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMCompiler$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMCompiler, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_lang_VMCompiler$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMCompiler$object *this)
{
	struct _jc_java_lang_VMCompiler$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(51);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMCompiler$methods[] = {
	&_jc_java_lang_VMCompiler$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMCompiler$method_info$command$9c4610a0259285ef,
	&_jc_java_lang_VMCompiler$method_info$compileClass$258fd65025401c03,
	&_jc_java_lang_VMCompiler$method_info$compileClasses$f9c43047d6e51ee8,
	&_jc_java_lang_VMCompiler$method_info$disable$76bb9c74f42e72e3,
	&_jc_java_lang_VMCompiler$method_info$enable$d5c88e4ee7026bca
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMCompiler$instanceof_hash_bucket_95[] = {
	&_jc_java_lang_VMCompiler$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMCompiler$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMCompiler$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[95]=	_jc_java_lang_VMCompiler$instanceof_hash_bucket_95,
	[101]=	_jc_java_lang_VMCompiler$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMCompiler$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMCompiler$vtype _jc_java_lang_VMCompiler$type = {
    .type= {
	.name=			"java/lang/VMCompiler",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x1ec1b2c5fdf4b5df),
		.source_file=		"VMCompiler.java",
		.instance_size=		sizeof(_jc_java_lang_VMCompiler$refs) + sizeof(_jc_java_lang_VMCompiler$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_lang_VMCompiler$methods) / sizeof(*_jc_java_lang_VMCompiler$methods),
		.methods=		_jc_java_lang_VMCompiler$methods,
		.instanceof_hash_table=	_jc_java_lang_VMCompiler$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_VMCompiler$class_depends) / sizeof(*_jc_java_lang_VMCompiler$class_depends),
		.class_depends=		_jc_java_lang_VMCompiler$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMCompiler= {
	},
    }
};
